| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeig3dj5jhsowlvg3t73kgobf6xn4nka7rkttakdb2gwsg5bp7rt7q4` | A protocol for ABCI requests and responses.                                                                                |
| connection/valory/abci/0.1.0                                  | `bafybeifzhmuvaqj5mnib65u5cqbmfpixjkow6iuh43ofricdpwdtjwawya` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeigr2cipad23aebjpnqtzpgymiwrwgmnior2fk4inbscdnqyl5epla` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeif3gj5a5n6humzzsc3hacmfvfdqltzo7ibc7vvtisv3ppmbzxbkui` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeialw5eaa4v54s7i3sjsuy6d5k624quhxhziqntwq5hnz4g646sb7m` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeibkj4pm6ziqh2fl3xfsjiou4ibnxlipmvmqhgvc7xwpnaddbtxzli` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeihtfmbzsjwsz7kmujzc4bofyoxckekbdi643f762tj3fe4witgjqu` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeidzttjrfn3kfxubr24axouytshsm57sjl2232g2z3wlitk6dl32em` | Service Manager contract                                                                                                   |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeigno3phsoafjzp2jja4env2bhopy3jnnvl7zbkdt7f7cjku6i2x3e` | IPFS e2e testing application.                                                                                              |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeidysb7gbhekavv2b3q6xl6rrlsjysosaqb63zbwq72kprsuhelisa` | Agent for testing the ABCI connection.                                                                                     |
| contract/valory/service_registry/0.1.0                        | `bafybeigxkx7pcz7blgcxtuga6c2z3fmrarcisauskusc64xulujs342rcq` | Service Registry contract                                                                                                  |
| protocol/valory/tendermint/0.1.0                              | `bafybeicusvezoqlmyt6iqomcbwaz3xkhk2qf3d56q5zprmj3xdxfy64k54` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeic72ncgqbzoz2guj4p4yjqulid7mv6yroeh65hxznloamoveeg7hq` | A protocol specification for IPFS requests and responses.                                                                  |
| skill/valory/abstract_abci/0.1.0                              | `bafybeiet34ju7typtkqyfn572sacef5krrsb6d4vpfnviqi6kzunje3xny` | The abci skill provides a template of an ABCI application.                                                                 |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeic3cfap5mbdfb67iejg6zaobtpgvxoltckdgbeovwc7gpzvjz2md4` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeibdljcw2wchyderkonobpdpyb36yioagqcaoqldydw5bi6vvempma` | abstract round-based ABCI application                                                                                      |
| contract/valory/multisend/0.1.0                               | `bafybeigjywkl7hydjsrkogob3xebj2ifhqwmfhhxoeyrndzhhxi5u6amey` | MultiSend contract                                                                                                         |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeiaeu47qmeeqipn6jnz4ymbxwqb66axvx3ddzocnni4zehbhiupc54` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeidqcszsitlmsofegmbprny22hqlent2o6luxng5a46gplytexrtbq` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeidprdrxzbloz5imufkbpvetvkhywdvq3fopbhdzztfnud4onsdsce` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeif33wyu6w7yrrhyacpt627i5g6nec2kiepsm5xx2b44zq657dch3a` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeid7pgblr236ylxqppn4srr72jxt4wz52ntd4ingwy75hju3hvnjay` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeiaqdfulxamdshw7fykfkqvkpvjb5bnmhv7ffrjiwdi4ktiulklx6q` | A client for the ABCI counter application.                                                                                 |
| skill/valory/hello_world_abci/0.1.0                           | `bafybeideg33qmn5lu557sztwed2w4bpqy46no5xxi7w63l2amcsjbu3uei` | Hello World ABCI application.                                                                                              |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeiap3ranmfbvg3vxevkw6hoj57blklrn653j2apj5u7q22nmfeh3ru` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeighlmchhkwyjuuciybx6ymqg2trfvwo2nsh7xbohb7yx22vz2uaay` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeihpnfzje34kszpdzblxvs63bbwnd6st6vtf3j246wex2y7a6k743q` | ABCI application for testing the ABCI connection.                                                                          |
| agent/valory/abstract_abci/0.1.0                              | `bafybeic26jek7pmiakwd6xpp6p2o42hoe5vt3qriwl2dtune42quzsgb44` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeid3yrkbydawyhjlvpfje73hkb5xvsnxamaef4rurtggiei4zcl7mm` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeihfvoaeh6s7idwqxcfs4fpil4mbtvg6jugpul34p335ziztq4r5pi` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/hello_world/0.1.0                                | `bafybeihnkrlyxkqdyn5nyxpg5nqgl6qziksvm7jbdtw4zt2tsnewqpshjy` | Hello World ABCI example.                                                                                                  |
| agent/valory/register_reset/0.1.0                             | `bafybeibffm7givuy5gamdfxbdaoctuqxbvi662mbd64gt3vc4n6pi7usvm` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeigzjl3o45epcmnkxjfe2aq7ippg66uicjtkp6obvpas7plyxzowhy` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeiacoy2gpru367sw4zewsdssggxrdtebfcixkazsc6hrkymo764vxa` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeicdebn4vd4vyps2em527hzzywk5joh3og7sivjjoi6p46jkljwnhm` | Agent for testing the ABCI connection.                                                                                     |
| service/valory/counter/0.1.0                                  | `bafybeiaw2ztzj4elyizxv4vbqui3unuatclrbrmltbv5dqv53yhl5hrvna` | A set of agents incrementing a counter                                                                                     |
| service/valory/hello_world/0.1.0                              | `bafybeiboenr2l5pgrov6dtlyx5mjop4odgrr6u4fhasc57a2g2sec5r43a` | A simple demonstration of a simple ABCI application                                                                        |
| service/valory/register_reset/0.1.0                           | `bafybeigh6pfcy4rekymgbqphhpob4yw4vfq4i4cqgisphppeuxjpeiovne` | Test and debug tendermint reset mechanism.                                                                                 |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeib6q2jikjllwekq3nvtnbqtl6aq2idrsva3xqyfnxvx3tfgvm7c3m` | ABCI application for dummy skill that registers and resets                                                                 |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeih77mwmsbjj7ns2a6zajsylpqxch2ld34as66zgmdde3v5glrzxxq` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| contract/valory/multicall2/0.1.0                              | `bafybeigywp4gpl6lel2bemehbvevpfflnwnpjaq3wnb7o7rjnwzqrlnijq` | The MakerDAO multicall2 contract.                                                                                          |
| protocol/open_aea/signing/1.0.0                               | `bafybeibqlfmikg5hk4phzak6gqzhpkt6akckx7xppbp53mvwt6r73h7tk4` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeignmc5uh3vgpuckljcj2tgg7hdqyytkm6m5b6v6mxtazdcvubibva` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeifyoio7nlh5zzyn5yz7krkou56l22to3cwg7gw5v5o3vxwklibhty` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeibo4bdtcrxi2suyzldwoetjar6pqfzm6vt5xal22ravkkcvdmtksi` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeidv6wxpjyb2sdyibnmmum45et4zcla6tl63bnol6ztyoqvpl4spmy` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeidykl4elwbcjkqn32wt5h4h7tlpeqovrcq3c5bcplt6nhpznhgczi` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeicgfupeudtmvehbwziqfxiz6ztsxr5rxzvalzvsdsspzz73o5fzfi` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeidwcobzb7ut3efegoedad7jfckvt2n6prcmd4g7xnkm6hp6aafrva` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
